% "Nsim" est le nombre de simulations demandées.
function GS_naif_comm (Nsim)
succes = 0;
% Boucle de Monte-Carlo.
for i = 1: Nsim
    % "lesdes" est ce qu'affichent les dés. On a choisi d'utiliser la
    % fonction « partie entière supérieure », notée "ceil", grâce à
    % laquelle on simule plus élégamment un entier uniforme entre 1 et n
    % (en l'occurrence n=6) — alors que "floor" s'utilise plutôt pour une
    % simulation entre 0 et n-1. Notez l'utilisation de la syntaxe
    % rand(n,m) qui simule une matrice n*m dont les cases sont i.i.d.
    % Uniforme(0,1).
    lesdes = ceil (6 * rand (1, 5));
    % Première étape de relancer. On va relancer tous les dés qui affichent
    % 1, et pour chaque autre chiffre, ne garder qu'un seul dé affichant ce
    % chiffre (s'il y en a). "dejavu(c)" est un booléen qui dit, à un
    % moment donné, si on a déjà vu un dé affichant le chiffre "c+1"
    % (attention au décalage d'indice !) parmi ceux obtenus à l'issue du
    % dernier relancer effectué.
    dejavu = zeros (1, 5);
    % On passe les dés en revue un par un.
    for j = 1: 5
        % Ici j'utilise une astuce de programmation diabolique (mais
        % tout-à-fait dispensable, rassurez-vous ;-) ) :
        % "dejavu(lesdes(j)-1)" n'a pas de sens si "lesdej(j)" vaut 1, ce
        % qui devrait alors provoquer un plantage... Mais il se trouve que,
        % lorsque Matlab (et beaucoup d'autres langages) doit évaluer le
        % résultat d'un "or" (ici représenté en tant que l'opérateur
        % binaire "||"), si le premier argument est « true », l'expression
        % est alors directement évaluée à « true » sans qu'on prenne la
        % peine de lire le second argument ! (Le même système fonctionne,
        % mutatis mutandis, avec "and"). En l'occurrence, si "lesdes(j)"
        % vaut 1, Matlab considèrera que la condition est remplie, et ne
        % cherchera donc pas à savoir ce que vaut "dejavu(lesdes(j)-1)", ce
        % qui évite le bogue. Par contre, si on avait inversé l'ordre des
        % opérandes du "||", le programme aurait effectivement bogué...
        if lesdes(j) == 1 || dejavu(lesdes(j) - 1)
            % Noter qu'ici nous ne respectons pas tout-à-fait le protocole
            % officiel du yahtzee : en effet, on est censé d'abord choisir
            % l'ensemble des dés à relancer, puis les relancer /tous à la
            % fois/... Bien entendu, la procédure proposée ici est en fait
            % équivalente, dans la mesure où on ne regarde pas (encore) le
            % résultat des dés relancés.
            lesdes(j) = ceil (6 * rand ());
        else
            dejavu(lesdes(j) - 1) = true;
        end
    end
    % Seconde étape de relancer. C'est exactement la même que la première !
    dejavu = zeros (1, 5);
    for j = 1: 5
        if lesdes(j) == 1 || dejavu(lesdes(j) - 1)
            lesdes(j) = ceil (6 * rand ());
        else
            dejavu(lesdes(j) - 1) = true;
        end
    end
    % L'objectif est-il atteint ?
    dejavu = zeros (1, 6);
    for j = 1:5
        dejavu(lesdes(j)) = true;
    end
    if (all (dejavu(2: 6)))
        succes = succes + 1;
    end
end
p = succes / Nsim;
fprintf ('Probabilité de succès: %f ± %f.\n', p, ...
    1.96 * sqrt (p * (1 - p) / Nsim));
return
end