% La fonction "grecque_base" estime p_0 par la méthode de Monte-Carlo.
% "Nsim" est le nombre de simulations demandées.
function grecque_base (Nsim)
% Paramètres généraux. De manière générale, c'est une bonne pratique de
% programmation que de nommer les paramètres généraux au début du
% programme, et de ne plus utiliser ensuite que leurs expressions
% littérales. Ainsi, il suffira de changer ces lignes de façon adéquate
% pour calculer p_1 plutôt que p_0.
Njours = 5;
seuil = 2;
moy_increment = -.2;
var_increment = 1.;
% Début de l'algorithme de Monte-Carlo.
succes = 0;
% Chaque passage dans la boucle de Monte-Carlo correspond à une simulation
% du phénomène aléatoire.
for i = 1: Nsim
    % "cours(j)" sera la valeur du cours de l'actif au jour j; on commence
    % par allouer la mémoire pour ces données.
    cours = zeros (Njours);
    % "actif" est la valeur courante de l'actif, initialisée au jours 0.
    actif = 0;
    % Évolution de l'actif.
    for j = 1: Njours
        increment = moy_increment + sqrt (var_increment) * randn ();
        actif = actif + increment;
        cours(j) = actif;
    end
    % Il faut tester si le cours a dépassé la valeur seuil. "test" dira si
    % le seuil a été dépassé ou non.
    test = false;
    for j = 1: Njours
        if cours(j) > seuil
            test = true;
        end
    end
    % On met à jour le nombre de succès, en utilisant la conversion
    % implicite des booléens vers les nombres.
    succes = succes + test;
end
% La fin du code est classique...
p = succes / Nsim;
var_f = p - p * p;
var_estr = var_f / Nsim;
fprintf ('p_0 vaut %f ± %f.\n', p, 1.96 * sqrt (var_estr));
return
end

