% La fonction "grecque_coupl" estime p_1-p_0 par la méthode de Monte-Carlo,
% en utilisant la technique de couplage. "Nsim" est le nombre de
% simulations demandées.
function grecque_coupl (Nsim)
% Paramètres généraux. Comme on a deux phénomènes à simuler, certains
% paramètres sont dédoublés.
Njours = 5;
moy_incr_0 = -.2;
moy_incr_1 = -.18;
var_incr_0 = 1.;
var_incr_1 = 1.1;
seuil = 2;
% Début de l'algorithme de Monte-Carlo. Notez qu'on n'est plus en train
% d'évaluer l'espérance d'une simple indicatrice; il faut donc compter
% séparément total et total des carrés.
tot_f = 0;
tot_f2 = 0;
% Chaque passage dans la boucle de Monte-Carlo correspond à une simulation
% /couplée/ du /double/ phénomène aléatoire.
for i = 1: Nsim
    % Comme il y a maintenant deux façons différentes d'utiliser l'aléa, il
    % y a maintenant "cours_0" et "cours_1", etc.
    cours_0 = zeros (Njours);
    cours_1 = zeros (Njours);
    actif_0 = 0;
    actif_1 = 0;
    for j = 1: Njours
        % Ici réside le cœur du couplage : on utilise la /même/ source
        % aléatoire "alea" (en l'occurrence une loi normale standard) pour
        % simuler les lois pourtant /différentes/ des deux incréments !
        alea = randn ();
        increment_0 = moy_incr_0 + sqrt (var_incr_0) * alea;
        increment_1 = moy_incr_1 + sqrt (var_incr_1) * alea;
        actif_0 = actif_0 + increment_0;
        actif_1 = actif_1 + increment_1;
        cours_0(j) = actif_0;
        cours_1(j) = actif_1;
    end
    test_0 = false;
    test_1 = false;
    for j = 1: Njours
        if cours_0(j) > seuil
            test_0 = true;
        end
        if cours_1(j) > seuil
            test_1 = true;
        end
    end
    % La fonction d'intérêt "f" est la différence entre les indicatrices du
    % succès dans le cas 1 et du succès dans le cas 0.
    f = test_1 - test_0;
    % Notre méthode de Monte-Carlo porte maintenant sur la fonction
    % d'intérêt f, c'est donc simplement en fonction d'elle qu'on doit
    % procéder... !
    tot_f = tot_f + f;
    tot_f2 = tot_f2 + f * f;
end
moy_f = tot_f / Nsim;
moy_f2 = tot_f2 / Nsim;
var_f = moy_f2 - moy_f * moy_f;
var_estr = var_f / Nsim;
fprintf ('p_1 - p_0 vaut %f ± %f.\n', moy_f, 1.96 * sqrt (var_estr));
return
end